Skip to contents

Builds an extended quarterly dataset by chaining the current history with the pseudo-forecast.

Usage

make_data_gets(
  cfg = load_forecast_cfg(),
  data_main = NULL,
  existing_forecast = NULL
)

Arguments

cfg

List-like configuration returned by [load_forecast_cfg()].

data_main

Optional preloaded history (ts-boxable object). When `NULL`, the function reads the history csv from disk.

existing_forecast

Optional pseudo-forecast dataset (ts-boxable object) When `NULL`, the function reads the csv from disk.

Value

Invisible list with xts object containing the extended quarterly dataset.