Skip to contents

Combines the current forecast, previous vintage, and history to create interactive HTML plots (and optionally annual summaries) for selected series.

Usage

plot_forecast(
  cfg = load_forecast_cfg(),
  forecast = NULL,
  comparison_forecast = NULL,
  history = NULL
)

Arguments

cfg

Configuration list from [load_forecast_cfg()].

forecast

Optional xts/tibble override for the current forecast.

comparison_forecast

Optional override for the previous forecast data.

history

Optional override for historical data.

Value

Invisible list containing the plot objects, combined data, and the file path of the rendered HTML report.